@@ -2,7 +2,7 @@ op2M <- hutilscpp:::op2M
 M2op <- hutilscpp:::M2op
 Cop2M <- hutilscpp:::Cop2M
 operators <- c("!=", "==", ">=", "<=", ">", "<", "%in%", "%between%", "%(between)%",
-               "%]between[%")
+               "%]between[%", "%notin%")
 expect_equal(operators, M2op(seq_along(operators)))
 
 expect_equal(sapply(operators, op2M), sapply(operators, Cop2M))
@@ -10,4 +10,5 @@ expect_equal(op2M("foo"), 0L)
 expect_equal(Cop2M("foo"), 0L)
 expect_equal(Cop2M(""), 0L)
 expect_equal(op2M(""), 0L)
+expect_true(Cop2M("%notin%") > 0)
 
